=========
Changelog
=========

0.2.0
=====

:Date: 2020-10-05

* First official release.
* Fix LICENSE.
* Fix CI builds (some tests still xfail although output is similar to expected).
* Tidy up packaging, metadata and infrastructure.

0.1.0 [DELETED]
===============

:Date: 2020-09-15

* Released from a non-maintainer fork (thanks to `@kyprifog <https://github.com/kyprifog>`_ for inspiring some cleanup).
* Incorrect LICENSE.
* Release has been deleted.
